@@ -177,6 +177,29 @@ model_4 %>%
   tidy_add_term_labels() %>%
   print_table()
 
+## -----------------------------------------------------------------------------
+model_logit <- glm(response ~ age + trt + grade, trial, family = binomial)
+
+model_logit %>%
+  tidy_and_attach() %>%
+  tidy_add_pairwise_contrasts() %>%
+  print_table()
+
+model_logit %>%
+  tidy_and_attach(exponentiate = TRUE) %>%
+  tidy_add_pairwise_contrasts() %>%
+  print_table()
+
+model_logit %>%
+  tidy_and_attach(exponentiate = TRUE) %>%
+  tidy_add_pairwise_contrasts(pairwise_reverse = FALSE) %>%
+  print_table()
+
+model_logit %>%
+  tidy_and_attach(exponentiate = TRUE) %>%
+  tidy_add_pairwise_contrasts(keep_model_terms = TRUE) %>%
+  print_table()
+
 ## ---- echo=FALSE--------------------------------------------------------------
 # nolint start
 tibble::tribble(
@@ -187,7 +210,7 @@ tibble::tribble(
   "var_type", "`tidy_identify_variables()`", "One of \"intercept\", \"continuous\", \"dichotomous\", \"categorical\", \"interaction\", \"ran_pars\" or \"ran_vals\"",
   "var_nlevels", "`tidy_identify_variables()`", "Number of original levels for categorical variables",
   "contrasts", "`tidy_add_contrasts()`", "Contrasts used for categorical variables.<br /><em>Require \"variable\" column. If needed, will automatically apply `tidy_identify_variables()`.</em>",
-  "contrasts_type", "`tidy_add_contrasts()`", "Type of contrasts (\"treatment\", \"sum\", \"poly\", \"helmert\", \"other\" or \"no.contrast\")",
+  "contrasts_type", "`tidy_add_contrasts()`", "Type of contrasts (\"treatment\", \"sum\", \"poly\", \"helmert\", \"other\" or \"no.contrast\"). \"pairwise\ is used for pairwise contrasts computed with `tidy_add_pairwise_contrasts()`.",
   "reference_row", "`tidy_add_reference_rows()`", "Logical indicating if a row is a reference row for categorical variables using a treatment or a sum contrast. Is equal to `NA` for variables who do not have a reference row.<br /><em>Require \"contrasts\" column. If needed, will automatically apply `tidy_add_contrasts()`.<br />`tidy_add_reference_rows()` will not populate the label of the reference term. It is therefore better to apply `tidy_add_term_labels()` after `tidy_add_reference_rows()` rather than before.</em>",
   "var_label", "`tidy_add_variable_labels()`", "String of variable labels from the model. Columns labelled with the `labelled` package are retained. It is possible to pass a custom label for an interaction term with the `labels` argument. <br /><em>Require \"variable\" column. If needed, will automatically apply `tidy_identify_variables()`.",
   "label", "`tidy_add_term_labels()`", "String of term labels based on (1) labels provided in `labels` argument if provided; (2) factor levels for categorical variables coded with treatment, SAS or sum contrasts; (3) variable labels when there is only one term per variable; and (4) term name otherwise.<br /><em>Require \"variable_label\" column. If needed, will automatically apply `tidy_add_variable_labels()`.<br />Require \"contrasts\" column. If needed, will automatically apply `tidy_add_contrasts()`.</em>",
@@ -209,6 +232,7 @@ tibble::tribble(
 tibble::tribble(
   ~Attribute, ~Function, ~Description,
   "exponentiate", "`tidy_and_attach()`", "Indicates if estimates were exponentiated",
+  "conf.level", "`tidy_and_attach()`", "Level of confidence used for confidence intervals",
   "coefficients_type", "`tidy_add_coefficients_type()`", "Type of coefficients",
   "coefficients_label", "`tidy_add_coefficients_type()`", "Coefficients label",
   "variable_labels", "`tidy_add_variable_labels()`",
